
RELEASE_VERSION='0.0.413654611'
BUILD_DATE='Mon Nov 22 08:31:20 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-t4krtqay-project-28359933-concurrent-0s4r27 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1805857166'
GIT_COMMIT_SHA='6245ce088dcc24cdadc66c9ab23ba3e784b1b4f9'
GIT_BRANCH='main'
